==> haskell-data-default-instances-dlist-0.0.1-78-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-instances-dlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-default-instances-dlist
version:              0.0.1
visibility:           public
id:                   data-default-instances-dlist-0.0.1-13uPyJ8kNxSCMixtRkUuze
key:                  data-default-instances-dlist-0.0.1-13uPyJ8kNxSCMixtRkUuze
license:              BSD-3-Clause
maintainer:           <l.mai@web.de>
author:               Lukas Mai
synopsis:             Default instances for types in dlist
category:             Data
abi:                  ebc32172648cf74087e6d4025d1a690d
exposed:              True
exposed-modules:      Data.Default.Instances.DList
import-dirs:
    /usr/lib/ghc-8.10.2/site-local/data-default-instances-dlist-0.0.1

library-dirs:
    /usr/lib/ghc-8.10.2/site-local/data-default-instances-dlist-0.0.1

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/data-default-instances-dlist-0.0.1

hs-libraries:         HSdata-default-instances-dlist-0.0.1-13uPyJ8kNxSCMixtRkUuze
depends:
    base-4.14.1.0 data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8
    dlist-1.0-3jl4pWydViv3yZtHdHS8Mt

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-dlist/html/data-default-instances-dlist.haddock

haddock-html:         /usr/share/doc/haskell-data-default-instances-dlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-default-instances-dlist-0.0.1-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-instances-dlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-default-instances-dlist
version:              0.0.1
visibility:           public
id:                   data-default-instances-dlist-0.0.1-KiTYGCXsMamBKtxy7nhh9V
key:                  data-default-instances-dlist-0.0.1-KiTYGCXsMamBKtxy7nhh9V
license:              BSD-3-Clause
maintainer:           <l.mai@web.de>
author:               Lukas Mai
synopsis:             Default instances for types in dlist
category:             Data
abi:                  933044645e190e0bc794d050c5eb160f
exposed:              True
exposed-modules:      Data.Default.Instances.DList
import-dirs:
    /usr/lib/ghc-8.10.2/site-local/data-default-instances-dlist-0.0.1

library-dirs:
    /usr/lib/ghc-8.10.2/site-local/data-default-instances-dlist-0.0.1

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/data-default-instances-dlist-0.0.1

hs-libraries:         HSdata-default-instances-dlist-0.0.1-KiTYGCXsMamBKtxy7nhh9V
depends:
    base-4.14.1.0 data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8
    dlist-1.0-5ej84cv0IrB48BysmcUNjs

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-dlist/html/data-default-instances-dlist.haddock

haddock-html:         /usr/share/doc/haskell-data-default-instances-dlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
